function [hfig, mat] = diptomatGM(dip, GM)
%diptomat converts a DIPimage format image into MATLAB format and displays it.
%
% INPUT:
%    dip   DIPimage image
%    GM    [OPTIONAL] establish GM coloring if provided
%
% OUTPUT:
%    mat   MATLAB image created from dip

   mat_dip = squeeze(im2mat(dip));
   dim = size(mat_dip);

   % Channel 1 is red, 2 is green, 3 is blue, so 1+2 is yellow, 1+3 is magenta,
   % 2+3 is cyan.  Here, we are assuming channel 3 is empty, so using it and
   % channel 1 to transform red images into magenta.
   mat = uint8(zeros([dim(1:2), 3]));
   if numel(dim) == 2
      mat(:, :, 1) = mat_dip ./ max(max(mat_dip)) * 255; % R
   else
      if ~exist('GM', 'var')
         mat(:,:,1) = mat_dip(:, :, 1) ./ max(max(mat_dip(:, :, 1))) * 255; % R
         mat(:,:,2) = mat_dip(:, :, 2) ./ max(max(mat_dip(:, :, 2))) * 255; % G
         mat(:,:,3) = mat_dip(:, :, 3) ./ max(max(mat_dip(:, :, 3))) * 255; % B
      else
         mat(:,:,1) = mat_dip(:, :, 1) ./ max(max(mat_dip(:, :, 1))) * 255; % R
         mat(:,:,2) = mat_dip(:, :, 2) ./ max(max(mat_dip(:, :, 2))) * 255; % G
         mat(:,:,3) = mat_dip(:, :, 1) ./ max(max(mat_dip(:, :, 1))) * 255; % B
      end
   end

   % Interestingly, using hold on/off flips the direction of the y-axis!
   hfig = figure;
   image(mat);
   axis equal
   axis off

end
