function formatFilenames(start_DataDir)
% Read a series of files, creating a 4D DIP image to assess which frames
% should be excluded, and prints the filenames in the right format for
% 'badFrames.m'.

% Instructions: Run script, select files (JOINED channels), copy
% formatted filenames, and use created 4D-image to choose bad frames (if any).
% Navigate with 'n' and 'p' between different frames and 'b' and 'f' between
% different files.  To better assess if a frame is in focus, set Mapping to
% Manual (e.g., 80 to 3000) instead of Linear Stretch.

% IMPORTANT: Select file containing joined channels (datasetJoined)

% INPUT:
%    start_DataDir     start location to look for data files

close all
[file filedir]=uigetfile(fullfile(start_DataDir, 'joined_*.mat'), ...
                         'Select joined channels', 'MultiSelect','on');
% Just make sure file is a cell (in case only one file was selected).
if ~iscell(file)
   file = {file};
end

fieldsScan= 3; % Number of fields of view scanned, e.g., 3 or 8

allDatasets= newim(512,512,fieldsScan+1,size(file,2)+1);
for iiFile= 1:size(file,2)
    load([filedir file{iiFile}])
    allDatasets(:,:,0:fieldsScan,iiFile)= datasetJoined;
                                          %squeeze(dataset(:,:,1,:));
    fprintf('dat(%d).filename=''%s'';\n',iiFile,file{iiFile}(1:end-4))
    fprintf('badFrames{%d}= [];\n\n',iiFile)
end

% Display all the datasets so the user can look through them and find bad
% frames.
allDatasets
% use next (n) and previous (p) to move between frames and forwards (f)
% and backwards (b) to move between data sets.

fprintf('Done formatting filenames.\n');

end
