function joinSequentialChannels(start_DataDir, ImSZ, Indx)
% Join sequential channels (images), putting them into datasetJoined as
% separate quadrants of a bigger image.  datasetJoined is saved in the same
% directory as the original images, but with 'joined_' prepended to the
% filename.  The sequential images are contained in the files as dip_images,
% originally under the name 'dataset', but now generalized to an arbitrary
% name.

% INPUTS:
%    start_DataDir     start location to look for data files
%    ImSZ              linear image size (pixel)
%    Indx              x and y quadrant indices for DIPimage format---see
%                      datasetJoined definitions below

% Get file names selected by user
[fileName, newFiledir]=uigetfile(fullfile(start_DataDir, '*.mat'), ...
                                 'Select sequential channels',     ...
                                 'MultiSelect','on');
% Just make sure fileName is a cell (in case only one file was selected).
if ~iscell(fileName)
   fileName = {fileName};
end

% datasetJoined = newim(512,512,4);
datasetJoined = newim(2*ImSZ,2*ImSZ,4); %EB
for ii=1:size(fileName, 2)
    % Load file selected by user
    DATA = load([newFiledir, fileName{ii}]);
    % See what variable names were actually loaded.
    DATAvars = fieldnames(DATA);
    if numel(DATAvars) == 1 && strcmp(class(DATA.(DATAvars{1})), 'dip_image')
       dataset = DATA.(DATAvars{1});
    else
       error('%s does not contain only a dip_image!', fileName{ii});
    end
    %dataset = DATA.dataset;
    % Copy and paste the 3 channels (635, 561 and 488)
    %datasetJoined(  0:255, 256:511, :) = dataset(  0:255, 256:511,:, 1); % 635
    %datasetJoined(  0:255,   0:255, :) = dataset(  0:255,   0:255,:, 2); % 561
    %datasetJoined(256:511,   0:255, :) = dataset(256:511,   0:255,:, 3); % 488
    datasetJoined(Indx{3}{1}, Indx{3}{2}, :) = ...
          dataset(Indx{3}{1}, Indx{3}{2}, :, 1); % 635
    datasetJoined(Indx{2}{1}, Indx{2}{2}, :) = ...
          dataset(Indx{2}{1}, Indx{2}{2}, :, 2); % 561
    datasetJoined(Indx{1}{1}, Indx{1}{2}, :) = ...
          dataset(Indx{1}{1}, Indx{1}{2}, :, 3); % 488

    [pathstr,name,ext] = fileparts(fileName{ii});
    save([newFiledir 'joined_' name ext],'datasetJoined');
    pause(2) % pause 2 seconds between each file to prevent processing files 
    % in a different order than originally (processing of some files takes
    %longer than others)
end

fprintf('Done joining sequential channels.\n');

end
