function summaryPlots(start_DataDir, Channels)
% Produce various summary plots for the SiMPull analysis.  These include bar
% graphs of the number of fits in each channel and the percentage overlap of
% the overlayed fits.  The plots will be put in Figures, a subdirectory of the
% directory containing the results.mat file produced by overlayFitting.

% INPUTS:
%    start_DataDir     start location to look for data files
%    Channels          channel numbers that are being used

filedir = uigetdir(start_DataDir, 'Directory containing results.mat');
savedirFigs = fullfile(filedir, 'Figures');
if ~exist(savedirFigs, 'dir')
   mkdir(savedirFigs);
end

load(fullfile(filedir, 'results.mat'));
svfilename = regexprep(valuecell{2, 1}, '_[0-9]-[0-9]$', '');;

% Maximum channel number.
MaxChannels  = 3;
% These channels will be skipped.
SkipChannels = setdiff(1 : MaxChannels, Channels);
% These overlap plots will be created (488w561, 488w642, 488w561+642).
KeepOverlaps = [];
SkipOverlaps = [];
if ismember(2, Channels) && ismember(3, Channels)
   KeepOverlaps = [1, 2, 3];
   SkipOverlaps = [];
elseif ismember(2, Channels)
   KeepOverlaps = [1];
   SkipOverlaps = [2, 3];
elseif ismember(3, Channels)
   KeepOverlaps = [2];
   SkipOverlaps = [1, 3];
end

% Create bar graph of the number of fits to each channel.
Xlabels = {'488', ...
           '561', ...
           '642'};
Xlabels(SkipChannels) = [];
XLABELS = categorical(Xlabels);
XLABELS = reordercats(XLABELS, Xlabels);
mY = zeros(MaxChannels, 1);
sY = zeros(MaxChannels, 1);
if ismember(1, Channels)
   mY(1) = mean([valuecell{2:end, 2}]);
   sY(1) =  std([valuecell{2:end, 2}]);
end
if ismember(2, Channels)
   mY(2) = mean([valuecell{2:end, 3}]);
   sY(2) =  std([valuecell{2:end, 3}]);
end
if ismember(3, Channels)
   mY(3) = mean([valuecell{2:end, 4}]);
   sY(3) =  std([valuecell{2:end, 4}]);
end
mY(SkipChannels) = [];
sY(SkipChannels) = [];
% Total EGFR
%mY(1) = mean([valuecell{2:end, 3}] ./ [valuecell{2:end, 2}] * 100);
%sY(1) =  std([valuecell{2:end, 3}] ./ [valuecell{2:end, 2}] * 100);
figure;
hold on
bar(XLABELS, mY);
ylabel('Fits');
errorbar(mY, sY, '.', 'CapSize', 25);
hold off
saveas(gcf, fullfile(savedirFigs, [svfilename, '_fitsBar']), 'fig')
saveas(gcf, fullfile(savedirFigs, [svfilename, '_fitsBar']), 'png')

% Create percentage overlap bar graph.
%
% [numoverlap561w488 / size(TrackXY488, 1) * 100, ...
%  numoverlap642w488 / size(TrackXY488, 1) * 100, ...
%  numTripleOverlap  / size(TrackXY488, 1) * 100);
%
Xlabels = {'488 w/ 561', ...
           '488 w/ 642', ...
           '488 w/ 561+642'};
Xlabels(SkipOverlaps) = [];
XLABELS = categorical(Xlabels);
XLABELS = reordercats(XLABELS, Xlabels);
mY = zeros(MaxChannels, 1);
sY = zeros(MaxChannels, 1);
if ismember(1, KeepOverlaps)
   mY(1) = mean([valuecell{2:end, 9}]);
   sY(1) =  std([valuecell{2:end, 9}]);
end
if ismember(2, KeepOverlaps)
   mY(2) = mean([valuecell{2:end, 11}]);
   sY(2) =  std([valuecell{2:end, 11}]);
end
if ismember(3, KeepOverlaps)
   mY(3) = mean([valuecell{2:end, 13}]);
   sY(3) =  std([valuecell{2:end, 13}]);
end
mY(SkipOverlaps) = [];
sY(SkipOverlaps) = [];
figure;
hold on
bar(XLABELS, mY);
ylabel('Percentage');
errorbar(mY, sY, '.', 'CapSize', 25);
hold off
saveas(gcf, fullfile(savedirFigs, [svfilename, '_overlapBar']), 'fig')
saveas(gcf, fullfile(savedirFigs, [svfilename, '_overlapBar']), 'png')

fprintf('Done summary plots.\n');

end
